@@ -13,5 +13,7 @@ class Config(dict):
                 config = config[key]
             return cls(**config)
 
-
-local_config = Config.from_json(join(USER_HOME, ".config", "credentials.json"))
+try:
+    local_config = Config.from_json(join(USER_HOME, ".config", "credentials.json"))
+except FileNotFoundError:
+    local_config = None
\ No newline at end of file
