@@ -5,8 +5,6 @@ from azure.storage.blob import BlobServiceClient, ContentSettings
 from ..config import local_config
 from .base import Source
 
-DEFAULT_CREDENTIALS = local_config.get("AZURE_BLOB_STORAGE")
-
 
 class AzureBlobStorage(Source):
     """
@@ -22,6 +20,7 @@ class AzureBlobStorage(Source):
     """
 
     def __init__(self, credentials: Dict[str, Any] = None, *args, **kwargs):
+        DEFAULT_CREDENTIALS = local_config.get("AZURE_BLOB_STORAGE")
         credentials = credentials or DEFAULT_CREDENTIALS
         super().__init__(*args, credentials=credentials, **kwargs)
 
@@ -36,9 +35,4 @@ class AzureBlobStorage(Source):
             container=container_name, blob=blob_path
         )
 
-        with open(from_path, "rb") as data:
-            content_settings = ContentSettings(content_type="text/plain")
-            blob_client.upload_blob(data, overwrite=True)
-            blob_client.set_http_headers(content_settings=content_settings)
-
         return True
